==> openstack_cli-0.0.3.tar.gz: openstack_cli-0.0.3/README.md <==
# openstack

openstack is a poilerplate Python that encourages rapid development
and clean, pragmatic design. and we're support templates to your field
what ever you want. Thanks for checking it out.

## openstack CLI

The openstack CLI is a command-line interface for interacting with the openstack.sh platform. 


## Installation

Before installing openstack_cli, it is recommended to create a virtual environment to isolate it from your system Python installation. This can help to avoid conflicts with other packages and make it easier to manage dependencies. To create a virtual environment, run the following commands:

```bash
python -m venv myenv
source myenv/bin/activate
```

Replace `myenv` with the desired name of your virtual environment.
After creating the virtual environment, you can then go to next step:



To install openstack_cli from PyPI, you will need to have Python and pip installed on your system. If you don't have them, you can download them from [python.org](https://www.python.org/) and [pip.pypa.io](https://pip.pypa.io/en/stable/installation/).

Once you have Python and pip installed, run the following command in your terminal or command prompt:

```bash
pip install openstack_cli
```

This will download and install `openstack_cli` and its dependencies.

After installation, you can run `openstack_cli --version` by typing the following command in your 
terminal or command prompt:

```bash
openstack_cli --version
```

## usage.
With the openstack CLI, you can perform various tasks such as:


- `openstack login`: Log in to the openstack CLI.

- `openstack register`: This command will take you to the openstack.sh website to create a new account.

- `openstack logout`: Log out of the openstack CLI.

- `openstack gift ls`: Show all templates you have bought.

- `openstack gift ls -a`: Show all templates, even those you don't own.

- `openstack init`: Prompt for project name and choose a template from those you have bought.

- `openstack buy`: Choose a template to buy.

- `openstack config ls`: Show all configuration information for your user.

- `openstack config get [KEY]`: Show the value for a specific configuration key.

- `openstack config set [KEY] [VALUE]`: Set a new value for a specific configuration key.

- `openstack info`: Show some information about openstack.sh.

==> openstack_cli-0.0.6.tar.gz: openstack_cli-0.0.6/README.md <==
# openstack

openstack is a poilerplate Python that encourages rapid development
and clean, pragmatic design. and we're support templates to your field
what ever you want. Thanks for checking it out.

## openstack CLI

The openstack CLI is a command-line interface for interacting with the openstack.sh platform.

## Installation

Before installing openstack_cli, it is recommended to create a virtual environment to isolate it from your system Python installation. This can help to avoid conflicts with other packages and make it easier to manage dependencies. To create a virtual environment, run the following commands:

```bash
python -m venv myenv
source myenv/bin/activate
```

Replace `myenv` with the desired name of your virtual environment.
After creating the virtual environment, you can then go to next step:

To install openstack_cli from PyPI, you will need to have Python and pip installed on your system. If you don't have them, you can download them from [python.org](https://www.python.org/) and [pip.pypa.io](https://pip.pypa.io/en/stable/installation/).

Once you have Python and pip installed, run the following command in your terminal or command prompt:

```bash
pip install openstack_cli
```

This will download and install `openstack_cli` and its dependencies.

After installation, you can run `openstack --version` by typing the following command in your
terminal or command prompt:

```bash
openstack --version
```

## usage.

With the openstack CLI, you can perform various tasks such as:

- `openstack login`: Log in to the openstack CLI.

- `openstack register`: This command will take you to the openstack.sh website to create a new account.

- `openstack logout`: Log out of the openstack CLI.

- `openstack gift ls`: Show all templates you have bought.

- `openstack gift ls -a`: Show all templates, even those you don't own.

- `openstack init`: Prompt for project name and choose a template from those you have bought.

- `openstack buy`: Choose a template to buy.

- `openstack config ls`: Show all configuration information for your user.

- `openstack config get [KEY]`: Show the value for a specific configuration key.

- `openstack config set [KEY] [VALUE]`: Set a new value for a specific configuration key.

- `openstack info`: Show some information about openstack.sh.
